@@ -1,6 +1,7 @@
 import logging
 import shutil
 import subprocess
+import sys
 from configparser import ConfigParser
 from pathlib import Path
 from time import sleep
@@ -109,7 +110,7 @@ class InfEngineServer:
 
         if enable_logging:
             formatter = logging.Formatter(fmt=" * %(message)s")
-            handler = logging.StreamHandler()
+            handler = logging.StreamHandler(sys.stdout)
             handler.setFormatter(formatter)
             self._logger.addHandler(handler)
 
